@@ -167,13 +167,16 @@ def check_output(*popenargs, **kwargs):
 
 
 def open_project_cloud_site(client, project_id, stage):
-    assert stage in ("test", "live")
     project_data = client.get_project(project_id)
-    url = project_data["{}_status".format(stage)]["site_url"]
+    try:
+        url = project_data["{}_status".format(stage)]["site_url"]
+    except KeyError:
+        click.secho("Environment with the name '{}' does not exist.".format(stage), fg="red")
+        sys.exit(1)
     if url:
         click.launch(url)
     else:
-        click.secho("No {} server deployed yet.".format(stage), fg="yellow")
+        click.secho("No {} environment deployed yet.".format(stage), fg="yellow")
 
 
 def get_cp_url(client, project_id, section="dashboard"):
@@ -316,9 +319,6 @@ def json_dumps_unicode(d, **kwargs):
     return json.dumps(d, ensure_ascii=False, **kwargs).encode("utf-8")
 
 
-def get_available_environments():
-    return ["test", "live"]
-
 
 class Map(dict):
     """
